@@ -63,20 +63,6 @@ C5_rules <-
     )
   }
 
-#' @export
-print.C5_rules <- function(x, ...) {
-  cat("C5.0 Model Specification (", x$mode, ")\n\n", sep = "")
-  model_printer(x, ...)
-
-  if (!is.null(x$method$fit$args)) {
-    cat("Model fit template:\n")
-    print(show_call(x))
-  }
-
-  invisible(x)
-}
-
-
 # ------------------------------------------------------------------------------
 
 #' Updating a model specification
@@ -100,35 +86,19 @@ update.C5_rules <-
            parameters = NULL,
            trees = NULL, min_n = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
 
-    if (!is.null(parameters)) {
-      parameters <- check_final_param(parameters)
-    }
     args <- list(
       trees = enquo(trees),
       min_n = enquo(min_n)
     )
 
-    args <- update_main_parameters(args, parameters)
-
-    if (fresh) {
-      object$args <- args
-    } else {
-      null_args <- map_lgl(args, null_value)
-      if (any(null_args))
-        args <- args[!null_args]
-      if (length(args) > 0)
-        object$args[names(args)] <- args
-    }
-
-    new_model_spec(
-      "C5_rules",
-      args = object$args,
-      eng_args = object$eng_args,
-      mode = object$mode,
-      method = NULL,
-      engine = object$engine
+    update_spec(
+      object = object,
+      parameters = parameters,
+      args_enquo_list = args,
+      fresh = fresh,
+      cls = "C5_rules",
+      ...
     )
   }
 
