@@ -41,19 +41,6 @@ discrim_quad <-
     )
   }
 
-#' @export
-print.discrim_quad <- function(x, ...) {
-  cat("Quadratic Discriminant Model Specification (", x$mode, ")\n\n", sep = "")
-  model_printer(x, ...)
-
-  if (!is.null(x$method$fit$args)) {
-    cat("Model fit template:\n")
-    print(show_call(x))
-  }
-
-  invisible(x)
-}
-
 # ------------------------------------------------------------------------------
 
 #' @method update discrim_quad
@@ -64,26 +51,16 @@ update.discrim_quad <-
   function(object,
            regularization_method = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
+
     args <- list(regularization_method = rlang::enquo(regularization_method))
 
-    if (fresh) {
-      object$args <- args
-    } else {
-      null_args <- map_lgl(args, null_value)
-      if (any(null_args))
-        args <- args[!null_args]
-      if (length(args) > 0)
-        object$args[names(args)] <- args
-    }
-
-    new_model_spec(
-      "discrim_quad",
-      args = object$args,
-      eng_args = object$eng_args,
-      mode = object$mode,
-      method = NULL,
-      engine = object$engine
+    update_spec(
+      object = object,
+      parameters = NULL,
+      args_enquo_list = args,
+      fresh = fresh,
+      cls = "discrim_quad",
+      ...
     )
   }
 
