@@ -17,10 +17,14 @@
 #'  model is `"lm"`.
 #' @param penalty A non-negative number representing the total
 #'  amount of regularization (specific engines only).
-#' @param mixture A number between zero and one (inclusive) that is the
-#'  proportion of L1 regularization (i.e. lasso) in the model. When
-#'  `mixture = 1`, it is a pure lasso model while `mixture = 0` indicates that
-#'  ridge regression is being used (specific engines only).
+#' @param mixture A number between zero and one (inclusive) denoting the
+#'  proportion of L1 regularization (i.e. lasso) in the model.
+#'
+#'  * `mixture = 1` specifies a pure lasso model,
+#'  * `mixture = 0`  specifies a ridge regression model, and
+#'  * `0 < mixture < 1` specifies an elastic net model, interpolating lasso and ridge.
+#'
+#'  Available for specific engines only.
 #'
 #' @template spec-details
 #'
@@ -54,20 +58,6 @@ linear_reg <-
     )
   }
 
-#' @export
-print.linear_reg <- function(x, ...) {
-  cat("Linear Regression Model Specification (", x$mode, ")\n\n", sep = "")
-  model_printer(x, ...)
-
-  if (!is.null(x$method$fit$args)) {
-    cat("Model fit template:\n")
-    print(show_call(x))
-  }
-
-  invisible(x)
-}
-
-
 #' @export
 translate.linear_reg <- function(x, engine = x$engine, ...) {
   x <- translate.default(x, engine, ...)
@@ -105,38 +95,18 @@ update.linear_reg <-
            penalty = NULL, mixture = NULL,
            fresh = FALSE, ...) {
 
-    eng_args <- update_engine_parameters(object$eng_args, ...)
-
-    if (!is.null(parameters)) {
-      parameters <- check_final_param(parameters)
-    }
     args <- list(
       penalty = enquo(penalty),
       mixture = enquo(mixture)
     )
 
-    args <- update_main_parameters(args, parameters)
-
-    if (fresh) {
-      object$args <- args
-      object$eng_args <- eng_args
-    } else {
-      null_args <- map_lgl(args, null_value)
-      if (any(null_args))
-        args <- args[!null_args]
-      if (length(args) > 0)
-        object$args[names(args)] <- args
-      if (length(eng_args) > 0)
-        object$eng_args[names(eng_args)] <- eng_args
-    }
-
-    new_model_spec(
-      "linear_reg",
-      args = object$args,
-      eng_args = object$eng_args,
-      mode = object$mode,
-      method = NULL,
-      engine = object$engine
+    update_spec(
+      object = object,
+      parameters = parameters,
+      args_enquo_list = args,
+      fresh = fresh,
+      cls = "linear_reg",
+      ...
     )
   }
 
