@@ -1,20 +1,13 @@
-library(testthat)
-library(parsnip)
-library(dplyr)
-library(rlang)
-
-context("changing arguments and engine")
-
 test_that('pipe arguments', {
   mod_1 <- rand_forest() %>%
     set_args(mtry = 1)
   expect_equal(
-    quo_get_expr(mod_1$args$mtry),
+    rlang::quo_get_expr(mod_1$args$mtry),
     1
   )
   expect_equal(
-    quo_get_env(mod_1$args$mtry),
-    empty_env()
+    rlang::quo_get_env(mod_1$args$mtry),
+    rlang::empty_env()
   )
 
   mod_2 <- rand_forest(mtry = 2) %>%
@@ -23,12 +16,12 @@ test_that('pipe arguments', {
   var_env <- rlang::current_env()
 
   expect_equal(
-    quo_get_expr(mod_2$args$mtry),
+    rlang::quo_get_expr(mod_2$args$mtry),
     1
   )
   expect_equal(
-    quo_get_env(mod_2$args$mtry),
-    empty_env()
+    rlang::quo_get_env(mod_2$args$mtry),
+    rlang::empty_env()
   )
 
   expect_error(rand_forest() %>% set_args())
@@ -84,7 +77,9 @@ test_that("unavailable modes for an engine and vice-versa", {
   )
 
   expect_error(
-    proportional_hazards() %>% set_mode("regression"),
+    expect_message(
+      proportional_hazards() %>% set_mode("regression")
+    ),
     "'regression' is not a known mode"
   )
 
@@ -99,7 +94,9 @@ test_that("unavailable modes for an engine and vice-versa", {
   )
 
   expect_error(
-    proportional_hazards() %>% set_engine(),
+    expect_message(
+      proportional_hazards() %>% set_engine()
+    ),
     "No known engines for"
   )
 })
