@@ -1,10 +1,3 @@
-library(testthat)
-library(parsnip)
-
-# ------------------------------------------------------------------------------
-
-context("boosted tree execution with xgboost")
-source(test_path("helper-objects.R"))
 hpc <- hpc_data[1:150, c(2:5, 8)]
 
 num_pred <- names(hpc)[1:4]
@@ -19,27 +12,66 @@ test_that('xgboost execution, classification', {
 
   skip_if_not_installed("xgboost")
 
-  expect_error(
-    res <- parsnip::fit(
+  ctrl$verbosity <- 0L
+
+  set.seed(1)
+  wts <- ifelse(runif(nrow(hpc)) < .1, 0, 1)
+  wts <- importance_weights(wts)
+
+  expect_error({
+    set.seed(1)
+    res_f <- parsnip::fit(
       hpc_xgboost,
       class ~ compounds + input_fields,
       data = hpc,
       control = ctrl
-    ),
-    regexp = NA
+    )
+  },
+  regexp = NA
   )
-  expect_error(
-    res <- parsnip::fit_xy(
+  expect_error({
+    set.seed(1)
+    res_xy <- parsnip::fit_xy(
       hpc_xgboost,
-      x = hpc[, num_pred],
+      x = hpc[, c("compounds", "input_fields")],
       y = hpc$class,
       control = ctrl
-    ),
-    regexp = NA
+    )
+  },
+  regexp = NA
+  )
+  expect_error({
+    set.seed(1)
+    res_f_wts <- parsnip::fit(
+      hpc_xgboost,
+      class ~ compounds + input_fields,
+      data = hpc,
+      control = ctrl,
+      case_weights = wts
+    )
+  },
+  regexp = NA
+  )
+  expect_error({
+    set.seed(1)
+    res_xy_wts <- parsnip::fit_xy(
+      hpc_xgboost,
+      x = hpc[, c("compounds", "input_fields")],
+      y = hpc$class,
+      control = ctrl,
+      case_weights = wts
+    )
+  },
+  regexp = NA
   )
 
-  expect_true(has_multi_predict(res))
-  expect_equal(multi_predict_args(res), "trees")
+  expect_equal(res_f$fit$evaluation_log,     res_xy$fit$evaluation_log)
+  expect_equal(res_f_wts$fit$evaluation_log, res_xy_wts$fit$evaluation_log)
+  # Check to see if the case weights had an effect
+  expect_true(!isTRUE(all.equal(res_f$fit$evaluation_log, res_f_wts$fit$evaluation_log)))
+
+  expect_true(has_multi_predict(res_xy))
+  expect_equal(multi_predict_args(res_xy), "trees")
 
   expect_error(
     res <- parsnip::fit(
@@ -57,6 +89,9 @@ test_that('xgboost classification prediction', {
   skip_if_not_installed("xgboost")
 
   library(xgboost)
+
+  ctrl$verbosity <- 0L
+
   xy_fit <- fit_xy(
     hpc_xgboost,
     x = hpc[, num_pred],
@@ -64,7 +99,7 @@ test_that('xgboost classification prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(xy_fit$fit, newdata = xgb.DMatrix(data = as.matrix(hpc[1:8, num_pred])), type = "class")
+  xy_pred <- predict(extract_fit_engine(xy_fit), newdata = xgb.DMatrix(data = as.matrix(hpc[1:8, num_pred])), type = "class")
   xy_pred <- matrix(xy_pred, ncol = 4, byrow = TRUE)
   xy_pred <- factor(levels(hpc$class)[apply(xy_pred, 1, which.max)], levels = levels(hpc$class))
   expect_equal(xy_pred, predict(xy_fit, new_data = hpc[1:8, num_pred], type = "class")$.pred_class)
@@ -76,7 +111,7 @@ test_that('xgboost classification prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(form_fit$fit, newdata = xgb.DMatrix(data = as.matrix(hpc[1:8, num_pred])), type = "class")
+  form_pred <- predict(extract_fit_engine(form_fit), newdata = xgb.DMatrix(data = as.matrix(hpc[1:8, num_pred])), type = "class")
   form_pred <- matrix(form_pred, ncol = 4, byrow = TRUE)
   form_pred <- factor(levels(hpc$class)[apply(form_pred, 1, which.max)], levels = levels(hpc$class))
   expect_equal(form_pred, predict(form_fit, new_data = hpc[1:8, num_pred], type = "class")$.pred_class)
@@ -103,6 +138,8 @@ test_that('xgboost execution, regression', {
 
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   expect_error(
     res <- parsnip::fit(
       car_basic,
@@ -140,6 +177,8 @@ test_that('xgboost regression prediction', {
 
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   xy_fit <- fit_xy(
     car_basic,
     x = mtcars[, -1],
@@ -147,7 +186,7 @@ test_that('xgboost regression prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(xy_fit$fit, newdata = xgb.DMatrix(data = as.matrix(mtcars[1:8, -1])))
+  xy_pred <- predict(extract_fit_engine(xy_fit), newdata = xgb.DMatrix(data = as.matrix(mtcars[1:8, -1])))
   expect_equal(xy_pred, predict(xy_fit, new_data = mtcars[1:8, -1])$.pred)
 
   form_fit <- fit(
@@ -157,10 +196,10 @@ test_that('xgboost regression prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(form_fit$fit, newdata = xgb.DMatrix(data = as.matrix(mtcars[1:8, -1])))
+  form_pred <- predict(extract_fit_engine(form_fit), newdata = xgb.DMatrix(data = as.matrix(mtcars[1:8, -1])))
   expect_equal(form_pred, predict(form_fit, new_data = mtcars[1:8, -1])$.pred)
 
-  expect_equal(form_fit$fit$params$objective, "reg:squarederror")
+  expect_equal(extract_fit_engine(form_fit)$params$objective, "reg:squarederror")
 
 })
 
@@ -169,20 +208,23 @@ test_that('xgboost regression prediction', {
 test_that('xgboost alternate objective', {
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   spec <-
     boost_tree() %>%
     set_engine("xgboost", objective = "reg:pseudohubererror") %>%
     set_mode("regression")
 
   xgb_fit <- spec %>% fit(mpg ~ ., data = mtcars)
-  expect_equal(xgb_fit$fit$params$objective, "reg:pseudohubererror")
+  expect_equal(extract_fit_engine(xgb_fit)$params$objective, "reg:pseudohubererror")
 })
 
 
 test_that('submodel prediction', {
 
   skip_if_not_installed("xgboost")
-  library(xgboost)
+
+  ctrl$verbosity <- 0L
 
   reg_fit <-
     boost_tree(trees = 20, mode = "regression") %>%
@@ -191,7 +233,7 @@ test_that('submodel prediction', {
 
   x <-  xgboost::xgb.DMatrix(as.matrix(mtcars[1:4, -1]))
 
-  pruned_pred <- predict(reg_fit$fit, x, iterationrange = c(1, 6))
+  pruned_pred <- predict(extract_fit_engine(reg_fit), x, iterationrange = c(1, 6))
 
   mp_res <- multi_predict(reg_fit, new_data = mtcars[1:4, -1], trees = 5)
   mp_res <- do.call("rbind", mp_res$.pred)
@@ -202,11 +244,11 @@ test_that('submodel prediction', {
   class_fit <-
     boost_tree(trees = 20, mode = "classification") %>%
     set_engine("xgboost") %>%
-    fit(churn ~ ., data = wa_churn[-(1:4), c("churn", vars)])
+    fit(churn ~ ., data = wa_churn[-(1:4), c("churn", vars)], control = ctrl)
 
   x <-  xgboost::xgb.DMatrix(as.matrix(wa_churn[1:4, vars]))
 
-  pred_class <- predict(class_fit$fit, x, iterationrange = c(1, 6))
+  pred_class <- predict(extract_fit_engine(class_fit), x, iterationrange = c(1, 6))
 
   mp_res <- multi_predict(class_fit, new_data = wa_churn[1:4, vars], trees = 5, type = "prob")
   mp_res <- do.call("rbind", mp_res$.pred)
@@ -222,6 +264,9 @@ test_that('submodel prediction', {
 
 test_that('validation sets', {
   skip_if_not_installed("xgboost")
+
+  ctrl$verbosity <- 0L
+
   expect_error(
     reg_fit <-
       boost_tree(trees = 20, mode = "regression") %>%
@@ -230,7 +275,7 @@ test_that('validation sets', {
     regex = NA
   )
 
-  expect_equal(colnames(reg_fit$fit$evaluation_log)[2], "validation_rmse")
+  expect_equal(colnames(extract_fit_engine(reg_fit)$evaluation_log)[2], "validation_rmse")
 
   expect_error(
     reg_fit <-
@@ -240,7 +285,7 @@ test_that('validation sets', {
     regex = NA
   )
 
-  expect_equal(colnames(reg_fit$fit$evaluation_log)[2], "validation_mae")
+  expect_equal(colnames(extract_fit_engine(reg_fit)$evaluation_log)[2], "validation_mae")
 
   expect_error(
     reg_fit <-
@@ -250,7 +295,7 @@ test_that('validation sets', {
     regex = NA
   )
 
-  expect_equal(colnames(reg_fit$fit$evaluation_log)[2], "training_mae")
+  expect_equal(colnames(extract_fit_engine(reg_fit)$evaluation_log)[2], "training_mae")
 
   expect_error(
     reg_fit <-
@@ -267,6 +312,9 @@ test_that('validation sets', {
 
 test_that('early stopping', {
   skip_if_not_installed("xgboost")
+
+  ctrl$verbosity <- 0L
+
   set.seed(233456)
   expect_error(
     reg_fit <-
@@ -276,8 +324,8 @@ test_that('early stopping', {
     regex = NA
   )
 
-  expect_equal(reg_fit$fit$niter - reg_fit$fit$best_iteration, 5)
-  expect_true(reg_fit$fit$niter < 200)
+  expect_equal(extract_fit_engine(reg_fit)$niter - extract_fit_engine(reg_fit)$best_iteration, 5)
+  expect_true(extract_fit_engine(reg_fit)$niter < 200)
 
   expect_error(
     reg_fit <-
@@ -312,6 +360,7 @@ test_that('xgboost data conversion', {
   mtcar_x <- mtcars[, -1]
   mtcar_mat <- as.matrix(mtcar_x)
   mtcar_smat <- Matrix::Matrix(mtcar_mat, sparse = TRUE)
+  wts <- 1:32
 
   expect_error(from_df <- parsnip:::as_xgb_data(mtcar_x, mtcars$mpg), regexp = NA)
   expect_true(inherits(from_df$data, "xgb.DMatrix"))
@@ -352,15 +401,25 @@ test_that('xgboost data conversion', {
   expect_warning(from_df <- parsnip:::as_xgb_data(mtcar_x, mtcars_y, event_level = "second"),
                  regexp = "`event_level` can only be set for binary variables.")
 
+  # case weights added
+  expect_error(wted <- parsnip:::as_xgb_data(mtcar_x, mtcars$mpg, weights = wts), regexp = NA)
+  expect_equal(wts, xgboost::getinfo(wted$data, "weight"))
+  expect_error(wted_val <- parsnip:::as_xgb_data(mtcar_x, mtcars$mpg, weights = wts, validation = 1/4), regexp = NA)
+  expect_true(all(xgboost::getinfo(wted_val$data, "weight") %in% wts))
+  expect_null(xgboost::getinfo(wted_val$watchlist$validation, "weight"))
+
 })
 
 
 test_that('xgboost data and sparse matrices', {
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   mtcar_x <- mtcars[, -1]
   mtcar_mat <- as.matrix(mtcar_x)
   mtcar_smat <- Matrix::Matrix(mtcar_mat, sparse = TRUE)
+  wts <- 1:32
 
   xgb_spec <-
     boost_tree(trees = 10) %>%
@@ -374,8 +433,20 @@ test_that('xgboost data and sparse matrices', {
   set.seed(1)
   from_sparse <- xgb_spec %>% fit_xy(mtcar_smat, mtcars$mpg)
 
-  expect_equal(from_df$fit, from_mat$fit)
-  expect_equal(from_df$fit, from_sparse$fit)
+  from_df$fit$handle <- NULL
+  from_mat$fit$handle <- NULL
+  from_sparse$fit$handle <- NULL
+
+
+  expect_equal(extract_fit_engine(from_df), extract_fit_engine(from_mat), ignore_function_env = TRUE)
+  expect_equal(extract_fit_engine(from_df), extract_fit_engine(from_sparse), ignore_function_env = TRUE)
+
+  # case weights added
+  expect_error(wted <- parsnip:::as_xgb_data(mtcar_smat, mtcars$mpg, weights = wts), regexp = NA)
+  expect_equal(wts, xgboost::getinfo(wted$data, "weight"))
+  expect_error(wted_val <- parsnip:::as_xgb_data(mtcar_smat, mtcars$mpg, weights = wts, validation = 1/4), regexp = NA)
+  expect_true(all(xgboost::getinfo(wted_val$data, "weight") %in% wts))
+  expect_null(xgboost::getinfo(wted_val$watchlist$validation, "weight"))
 
 })
 
@@ -386,6 +457,8 @@ test_that('argument checks for data dimensions', {
 
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   data(penguins, package = "modeldata")
   penguins <- na.omit(penguins)
 
@@ -398,17 +471,17 @@ test_that('argument checks for data dimensions', {
   penguins_dummy <- as.data.frame(penguins_dummy[, -1])
 
   expect_warning(
-    f_fit  <- spec %>% fit(species ~ ., data = penguins),
+    f_fit  <- spec %>% fit(species ~ ., data = penguins, control = ctrl),
     "1000 samples were requested"
   )
   expect_warning(
-    xy_fit <- spec %>% fit_xy(x = penguins_dummy, y = penguins$species),
+    xy_fit <- spec %>% fit_xy(x = penguins_dummy, y = penguins$species, control = ctrl),
     "1000 samples were requested"
   )
-  expect_equal(f_fit$fit$params$colsample_bynode, 1)
-  expect_equal(f_fit$fit$params$min_child_weight, nrow(penguins))
-  expect_equal(xy_fit$fit$params$colsample_bynode, 1)
-  expect_equal(xy_fit$fit$params$min_child_weight, nrow(penguins))
+  expect_equal(extract_fit_engine(f_fit)$params$colsample_bynode, 1)
+  expect_equal(extract_fit_engine(f_fit)$params$min_child_weight, nrow(penguins))
+  expect_equal(extract_fit_engine(xy_fit)$params$colsample_bynode, 1)
+  expect_equal(extract_fit_engine(xy_fit)$params$min_child_weight, nrow(penguins))
 
 })
 
@@ -416,6 +489,8 @@ test_that("fit and prediction with `event_level`", {
 
   skip_if_not_installed("xgboost")
 
+  ctrl$verbosity <- 0L
+
   data(penguins, package = "modeldata")
   penguins <- na.omit(penguins[, -c(1:2)])
 
@@ -441,9 +516,10 @@ test_that("fit and prediction with `event_level`", {
                                 nrounds = 10,
                                 watchlist = list("training" = xgbmat_train_1),
                                 objective = "binary:logistic",
-                                eval_metric = "auc")
+                                eval_metric = "auc",
+                                verbose = 0)
 
-  expect_equal(fit_p_1$fit$evaluation_log, fit_xgb_1$evaluation_log)
+  expect_equal(extract_fit_engine(fit_p_1)$evaluation_log, fit_xgb_1$evaluation_log)
 
   pred_xgb_1 <- predict(fit_xgb_1, x_pred)
   pred_p_1 <- predict(fit_p_1, new_data = penguins[1:4, ], type = "prob")
@@ -464,9 +540,10 @@ test_that("fit and prediction with `event_level`", {
                                   nrounds = 10,
                                   watchlist = list("training" = xgbmat_train_2),
                                   objective = "binary:logistic",
-                                  eval_metric = "auc")
+                                  eval_metric = "auc",
+                                  verbose = 0)
 
-  expect_equal(fit_p_2$fit$evaluation_log, fit_xgb_2$evaluation_log)
+  expect_equal(extract_fit_engine(fit_p_2)$evaluation_log, fit_xgb_2$evaluation_log)
 
   pred_xgb_2 <- predict(fit_xgb_2, x_pred)
   pred_p_2 <- predict(fit_p_2, new_data = penguins[1:4, ], type = "prob")
@@ -476,37 +553,40 @@ test_that("fit and prediction with `event_level`", {
 
 test_that("count/proportion parameters", {
   skip_if_not_installed("xgboost")
+
+  ctrl$verbosity <- 0L
+
   fit1 <-
     boost_tree(mtry = 7, trees = 4) %>%
     set_engine("xgboost") %>%
     set_mode("regression") %>%
     fit(mpg ~ ., data = mtcars)
-  expect_equal(fit1$fit$params$colsample_bytree, 1)
-  expect_equal(fit1$fit$params$colsample_bynode, 7/(ncol(mtcars) - 1))
+  expect_equal(extract_fit_engine(fit1)$params$colsample_bytree, 1)
+  expect_equal(extract_fit_engine(fit1)$params$colsample_bynode, 7/(ncol(mtcars) - 1))
 
   fit2 <-
     boost_tree(mtry = 7, trees = 4) %>%
     set_engine("xgboost", colsample_bytree = 4) %>%
     set_mode("regression") %>%
     fit(mpg ~ ., data = mtcars)
-  expect_equal(fit2$fit$params$colsample_bytree, 4/(ncol(mtcars) - 1))
-  expect_equal(fit2$fit$params$colsample_bynode, 7/(ncol(mtcars) - 1))
+  expect_equal(extract_fit_engine(fit2)$params$colsample_bytree, 4/(ncol(mtcars) - 1))
+  expect_equal(extract_fit_engine(fit2)$params$colsample_bynode, 7/(ncol(mtcars) - 1))
 
   fit3 <-
     boost_tree(trees = 4) %>%
     set_engine("xgboost") %>%
     set_mode("regression") %>%
     fit(mpg ~ ., data = mtcars)
-  expect_equal(fit3$fit$params$colsample_bytree, 1)
-  expect_equal(fit3$fit$params$colsample_bynode, 1)
+  expect_equal(extract_fit_engine(fit3)$params$colsample_bytree, 1)
+  expect_equal(extract_fit_engine(fit3)$params$colsample_bynode, 1)
 
   fit4 <-
     boost_tree(mtry = .9, trees = 4) %>%
     set_engine("xgboost", colsample_bytree = .1, counts = FALSE) %>%
     set_mode("regression") %>%
     fit(mpg ~ ., data = mtcars)
-  expect_equal(fit4$fit$params$colsample_bytree, .1)
-  expect_equal(fit4$fit$params$colsample_bynode, .9)
+  expect_equal(extract_fit_engine(fit4)$params$colsample_bytree, .1)
+  expect_equal(extract_fit_engine(fit4)$params$colsample_bynode, .9)
 
   expect_error(
     boost_tree(mtry = .9, trees = 4) %>%
