@@ -1,12 +1,3 @@
-library(testthat)
-library(parsnip)
-library(tibble)
-library(rlang)
-
-# ------------------------------------------------------------------------------
-
-context("random forest execution with ranger")
-source(test_path("helper-objects.R"))
 hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # ------------------------------------------------------------------------------
@@ -35,7 +26,6 @@ test_that('ranger classification execution', {
     ),
     regexp = NA
   )
-  expect_output(print(res), "parsnip model object")
 
   expect_error(
     res <- fit(
@@ -75,7 +65,7 @@ test_that('ranger classification execution', {
 
     control = caught_ctrl
   )
-  expect_true(inherits(ranger_form_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(ranger_form_catch), "try-error"))
 
   ranger_xy_catch <- fit_xy(
     bad_ranger_cls,
@@ -84,7 +74,7 @@ test_that('ranger classification execution', {
     x = lending_club[, num_pred],
     y = lending_club$Class
   )
-  expect_true(inherits(ranger_xy_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(ranger_xy_catch), "try-error"))
 
 })
 
@@ -99,7 +89,7 @@ test_that('ranger classification prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(xy_fit$fit, data = lending_club[1:6, num_pred])$prediction
+  xy_pred <- predict(extract_fit_engine(xy_fit), data = lending_club[1:6, num_pred])$prediction
   xy_pred <- colnames(xy_pred)[apply(xy_pred, 1, which.max)]
   xy_pred <- factor(xy_pred, levels = levels(lending_club$Class))
   expect_equal(
@@ -115,7 +105,7 @@ test_that('ranger classification prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(form_fit$fit, data = lending_club[1:6, c("funded_amnt", "int_rate")])$prediction
+  form_pred <- predict(extract_fit_engine(form_fit), data = lending_club[1:6, c("funded_amnt", "int_rate")])$prediction
   form_pred <- colnames(form_pred)[apply(form_pred, 1, which.max)]
   form_pred <- factor(form_pred, levels = levels(lending_club$Class))
   expect_equal(
@@ -138,7 +128,7 @@ test_that('ranger classification probabilities', {
     control = ctrl
   )
 
-  xy_pred <- predict(xy_fit$fit, data = lending_club[1:6, num_pred])$predictions
+  xy_pred <- predict(extract_fit_engine(xy_fit), data = lending_club[1:6, num_pred])$predictions
   xy_pred <- as_tibble(xy_pred)
   names(xy_pred) <- paste0(".pred_", names(xy_pred))
   expect_equal(
@@ -147,7 +137,7 @@ test_that('ranger classification probabilities', {
   )
 
   one_row <- predict(xy_fit, new_data = lending_club[1, num_pred], type = "prob")
-  expect_equivalent(xy_pred[1,], one_row)
+  expect_equal(xy_pred[1,], one_row)
 
   form_fit <- fit(
     rand_forest() %>% set_mode("classification") %>% set_engine("ranger", seed = 3566),
@@ -157,7 +147,7 @@ test_that('ranger classification probabilities', {
     control = ctrl
   )
 
-  form_pred <- predict(form_fit$fit, data = lending_club[1:6, c("funded_amnt", "int_rate")])$predictions
+  form_pred <- predict(extract_fit_engine(form_fit), data = lending_club[1:6, c("funded_amnt", "int_rate")])$predictions
   form_pred <- as_tibble(form_pred)
   names(form_pred) <- paste0(".pred_", names(form_pred))
   expect_equal(
@@ -219,7 +209,7 @@ test_that('ranger regression execution', {
     data = mtcars,
     control = caught_ctrl
   )
-  expect_true(inherits(ranger_form_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(ranger_form_catch), "try-error"))
 
   ranger_xy_catch <- fit_xy(
     bad_ranger_reg,
@@ -227,7 +217,7 @@ test_that('ranger regression execution', {
     x = mtcars[, num_pred],
     y = mtcars$mpg
   )
-  expect_true(inherits(ranger_xy_catch$fit, "try-error"))
+  expect_true(inherits(extract_fit_engine(ranger_xy_catch), "try-error"))
 
 })
 
@@ -242,7 +232,7 @@ test_that('ranger regression prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(xy_fit$fit, data = tail(mtcars[, -1]))$prediction
+  xy_pred <- predict(extract_fit_engine(xy_fit), data = tail(mtcars[, -1]))$prediction
 
   expect_equal(xy_pred, predict(xy_fit, new_data = tail(mtcars[, -1]))$.pred)
 
@@ -260,19 +250,21 @@ test_that('ranger regression intervals', {
     control = ctrl
   )
 
-  rgr_pred <- predict(xy_fit$fit, data = tail(mtcars[, -1]))$predictions
-  rgr_se <-
-    expect_warning(predict(xy_fit$fit, data = tail(mtcars[, -1]), type = "se")$se)
+  rgr_pred <- predict(extract_fit_engine(xy_fit), data = tail(mtcars[, -1]))$predictions
+  expect_warning(
+    rgr_se <-
+      predict(extract_fit_engine(xy_fit), data = tail(mtcars[, -1]), type = "se")$se
+  )
   rgr_lower <- rgr_pred - qnorm(0.035, lower.tail = FALSE) * rgr_se
   rgr_upper <- rgr_pred + qnorm(0.035, lower.tail = FALSE) * rgr_se
 
-  parsnip_int <-
-    expect_warning(
+  expect_warning(
+    parsnip_int <-
       predict(xy_fit, new_data = tail(mtcars[, -1]),
               type = "conf_int", std_error = TRUE, level = 0.93
       )
-    )
-  expect_equal(rgr_lower, parsnip_int$.pred_lower)
+  )
+  expect_equal(rgr_lower, parsnip_int$.pred_lower, ignore_formula_env = TRUE)
   expect_equal(rgr_upper, parsnip_int$.pred_upper)
   expect_equal(rgr_se, parsnip_int$.std_error)
 
@@ -291,7 +283,7 @@ test_that('additional descriptor tests', {
     y = mtcars$mpg,
     control = ctrl
   )
-  expect_equal(descr_xy$fit$mtry, 4)
+  expect_equal(extract_fit_engine(descr_xy)$mtry, 4)
 
   descr_f <- fit(
     rand_forest(mode = "regression", mtry = floor(sqrt(.cols())) + 1) %>%
@@ -299,7 +291,7 @@ test_that('additional descriptor tests', {
     mpg ~ ., data = mtcars,
     control = ctrl
   )
-  expect_equal(descr_f$fit$mtry, 4)
+  expect_equal(extract_fit_engine(descr_f)$mtry, 4)
 
   descr_xy <- fit_xy(
     rand_forest(mode = "regression", mtry = floor(sqrt(.cols())) + 1) %>%
@@ -308,7 +300,7 @@ test_that('additional descriptor tests', {
     y = mtcars$mpg,
     control = ctrl
   )
-  expect_equal(descr_xy$fit$mtry, 4)
+  expect_equal(extract_fit_engine(descr_xy)$mtry, 4)
 
   descr_f <- fit(
     rand_forest(mode = "regression", mtry = floor(sqrt(.cols())) + 1) %>%
@@ -316,11 +308,11 @@ test_that('additional descriptor tests', {
     mpg ~ ., data = mtcars,
     control = ctrl
   )
-  expect_equal(descr_f$fit$mtry, 4)
+  expect_equal(extract_fit_engine(descr_f)$mtry, 4)
 
   ##
 
-  exp_wts <- quo(c(min(.lvls()), 20, 10, 1))
+  exp_wts <- rlang::quo(c(min(.lvls()), 20, 10, 1))
 
   descr_other_xy <- fit_xy(
     rand_forest(mode = "classification", mtry = 2) %>%
@@ -329,8 +321,9 @@ test_that('additional descriptor tests', {
     y = hpc$class,
     control = ctrl
   )
-  expect_equal(descr_other_xy$fit$mtry, 2)
-  expect_equal(descr_other_xy$fit$call$class.weights, exp_wts)
+  expect_equal(extract_fit_engine(descr_other_xy)$mtry, 2)
+  expect_equal(extract_fit_engine(descr_other_xy)$call$class.weights, exp_wts,
+               ignore_formula_env = TRUE)
 
   descr_other_f <- fit(
     rand_forest(mode = "classification", mtry = 2) %>%
@@ -338,8 +331,9 @@ test_that('additional descriptor tests', {
     class ~ ., data = hpc,
     control = ctrl
   )
-  expect_equal(descr_other_f$fit$mtry, 2)
-  expect_equal(descr_other_f$fit$call$class.weights, exp_wts)
+  expect_equal(extract_fit_engine(descr_other_f)$mtry, 2)
+  expect_equal(extract_fit_engine(descr_other_f)$call$class.weights, exp_wts,
+               ignore_formula_env = TRUE)
 
   descr_other_xy <- fit_xy(
     rand_forest(mode = "classification", mtry = 2) %>%
@@ -348,8 +342,9 @@ test_that('additional descriptor tests', {
     y = hpc$class,
     control = ctrl
   )
-  expect_equal(descr_other_xy$fit$mtry, 2)
-  expect_equal(descr_other_xy$fit$call$class.weights, exp_wts)
+  expect_equal(extract_fit_engine(descr_other_xy)$mtry, 2)
+  expect_equal(extract_fit_engine(descr_other_xy)$call$class.weights, exp_wts,
+               ignore_formula_env = TRUE)
 
   descr_other_f <- fit(
     rand_forest(mode = "classification", mtry = 2) %>%
@@ -357,8 +352,9 @@ test_that('additional descriptor tests', {
     class ~ ., data = hpc,
     control = ctrl
   )
-  expect_equal(descr_other_f$fit$mtry, 2)
-  expect_equal(descr_other_f$fit$call$class.weights, exp_wts)
+  expect_equal(extract_fit_engine(descr_other_f)$mtry, 2)
+  expect_equal(extract_fit_engine(descr_other_f)$call$class.weights, exp_wts,
+               ignore_formula_env = TRUE)
 })
 
 
@@ -377,7 +373,7 @@ test_that('ranger classification prediction', {
   expect_false(has_multi_predict(xy_class_fit))
   expect_equal(multi_predict_args(xy_class_fit), NA_character_)
 
-  xy_class_pred <- predict(xy_class_fit$fit, data = hpc[c(1, 51, 101), 1:4])$prediction
+  xy_class_pred <- predict(extract_fit_engine(xy_class_fit), data = hpc[c(1, 51, 101), 1:4])$prediction
   xy_class_pred <- colnames(xy_class_pred)[apply(xy_class_pred, 1, which.max)]
   xy_class_pred <- factor(xy_class_pred, levels = levels(hpc$class))
 
@@ -396,7 +392,7 @@ test_that('ranger classification prediction', {
       control = ctrl
     )
 
-  xy_prob_pred <- predict(xy_prob_fit$fit, data = hpc[c(1, 51, 101), 1:4])$prediction
+  xy_prob_pred <- predict(extract_fit_engine(xy_prob_fit), data = hpc[c(1, 51, 101), 1:4])$prediction
   xy_prob_pred <- colnames(xy_prob_pred)[apply(xy_prob_pred, 1, which.max)]
   xy_prob_pred <- factor(xy_prob_pred, levels = levels(hpc$class))
 
@@ -405,7 +401,7 @@ test_that('ranger classification prediction', {
     predict(xy_prob_fit, new_data = hpc[c(1, 51, 101), 1:4])$.pred_class
   )
 
-  xy_prob_prob <- predict(xy_prob_fit$fit, data = hpc[c(1, 51, 101), 1:4], type = "response")
+  xy_prob_prob <- predict(extract_fit_engine(xy_prob_fit), data = hpc[c(1, 51, 101), 1:4], type = "response")
   xy_prob_prob <- as_tibble(xy_prob_prob$prediction)
   names(xy_prob_prob) <- paste0(".pred_", names(xy_prob_prob))
   expect_equal(
@@ -427,19 +423,21 @@ test_that('ranger classification intervals', {
     control = ctrl
   )
 
-  rgr_pred <- predict(lc_fit$fit, data = tail(lending_club))$predictions
-  rgr_se <- expect_warning(predict(lc_fit$fit, data = tail(lending_club), type = "se")$se)
+  rgr_pred <- predict(extract_fit_engine(lc_fit), data = tail(lending_club))$predictions
+  suppressWarnings(expect_warning(
+    rgr_se <- predict(extract_fit_engine(lc_fit), data = tail(lending_club), type = "se")$se
+  ))
   rgr_lower <- rgr_pred - qnorm(0.035, lower.tail = FALSE) * rgr_se
   rgr_upper <- rgr_pred + qnorm(0.035, lower.tail = FALSE) * rgr_se
   rgr_lower[rgr_lower < 0] <- 0
   rgr_upper[rgr_upper > 1] <- 1
 
-  parsnip_int <-
-    expect_warning(
+  suppressWarnings(expect_warning(
+    parsnip_int <-
       predict(lc_fit, new_data = tail(lending_club),
               type = "conf_int", std_error = TRUE, level = 0.93
       )
-    )
+  ))
   expect_equal(rgr_lower[, "bad"], parsnip_int$.pred_lower_bad)
   expect_equal(rgr_lower[, "good"], parsnip_int$.pred_lower_good)
   expect_equal(rgr_upper[, "bad"], parsnip_int$.pred_upper_bad)
@@ -470,8 +468,8 @@ test_that('ranger and sparse matrices', {
   set.seed(1)
   from_sparse <- rf_spec %>% fit_xy(mtcar_smat, mtcars$mpg)
 
-  expect_equal(from_df$fit, from_mat$fit)
-  expect_equal(from_df$fit, from_sparse$fit)
+  expect_equal(extract_fit_engine(from_df), extract_fit_engine(from_mat))
+  expect_equal(extract_fit_engine(from_df), extract_fit_engine(from_sparse))
 
   rf_spec <-
     rand_forest(trees = 10) %>%
@@ -499,19 +497,17 @@ test_that('argument checks for data dimensions', {
     set_engine("ranger") %>%
     set_mode("regression")
 
-  expect_warning(
-    f_fit  <- spec %>% fit(body_mass_g ~ ., data = penguins),
-    "(1000 samples)|(1000 columns)"
+  expect_snapshot(
+    f_fit  <- spec %>% fit(body_mass_g ~ ., data = penguins)
   )
-  expect_warning(
-    xy_fit <- spec %>% fit_xy(x = penguins[, -6], y = penguins$body_mass_g),
-    "(1000 samples)|(1000 columns)"
+  expect_snapshot(
+    xy_fit <- spec %>% fit_xy(x = penguins[, -6], y = penguins$body_mass_g)
   )
 
 
-  expect_equal(f_fit$fit$mtry, 6)
-  expect_equal(f_fit$fit$min.node.size, nrow(penguins))
-  expect_equal(xy_fit$fit$mtry, 6)
-  expect_equal(xy_fit$fit$min.node.size, nrow(penguins))
+  expect_equal(extract_fit_engine(f_fit)$mtry, 6)
+  expect_equal(extract_fit_engine(f_fit)$min.node.size, nrow(penguins))
+  expect_equal(extract_fit_engine(xy_fit)$mtry, 6)
+  expect_equal(extract_fit_engine(xy_fit)$min.node.size, nrow(penguins))
 
 })
